@@ -17,6 +17,7 @@
  *
  */
 
+#include <cmath>
 #include <iostream>
 #include "somoclu.h"
 #ifdef HAVE_R
@@ -76,7 +77,7 @@ void trainOneEpochDenseCPU(int itask, float *data, float *numerator,
                            unsigned int nVectorsPerRank, float radius,
                            float scale, string mapType, string gridType,
                            bool compact_support, bool gaussian, int *globalBmus,
-                           bool only_bmus) {
+                           bool only_bmus, float std_coeff) {
     unsigned int p1[2] = {0, 0};
     int *bmus;
 #ifdef HAVE_MPI
@@ -177,7 +178,7 @@ void trainOneEpochDenseCPU(int itask, float *data, float *numerator,
                                 dist = euclideanDistanceOnHexagonalToroidMap(som_x, som_y, bmus[2 * n], bmus[2 * n + 1], nSomX, nSomY);
                             }
                         }
-                        float neighbor_fuct = getWeight(dist, radius, scale, compact_support, gaussian);
+                        float neighbor_fuct = getWeight(dist, radius, scale, compact_support, gaussian, std_coeff);
 #ifdef HAVE_MPI
                         localDenominator[som_y * nSomX + som_x] += neighbor_fuct;
                         for (unsigned int d = 0; d < nDimensions; d++) {
@@ -204,9 +205,9 @@ void trainOneEpochDenseCPU(int itask, float *data, float *numerator,
                 } // Looping over data instances
 #ifndef HAVE_MPI // We update in-place
                 for (unsigned int d = 0; d < nDimensions; d++) {
-                    float newWeight = localNumerator[d] / localDenominator;
-                    if (newWeight > 0.0) {
-                        codebook[som_y * nSomX * nDimensions + som_x * nDimensions + d] = newWeight;
+                    if (localDenominator != 0) {
+                      float newWeight = localNumerator[d] / localDenominator;
+                      codebook[som_y * nSomX * nDimensions + som_x * nDimensions + d] = newWeight;
                     }
                 }
 #endif
